@@ -43,6 +43,7 @@ import decimal as decimal_
 
 Validate_simpletypes_ = True
 SaveElementTreeNode = True
+TagNamePrefix = ""
 if sys.version_info.major == 2:
     BaseStrType_ = basestring
 else:
@@ -194,12 +195,12 @@ class GeneratedsSuper(object):
 ##             'str_pretty_print': True,
 ##             'str_indent_level': 0,
 ##             'str_namespaceprefix': '',
-##             'str_name': None,
+##             'str_name': self.__class__.__name__,
 ##             'str_namespacedefs': '',
 ##         }
 ##         for n in settings:
 ##             if hasattr(self, n):
-##                 setattr(settings[n], self[n])
+##                 settings[n] = getattr(self, n)
 ##         if sys.version_info.major == 2:
 ##             from StringIO import StringIO
 ##         else:
