@@ -42,6 +42,7 @@ from lxml import etree as etree_
 
 Validate_simpletypes_ = True
 SaveElementTreeNode = True
+TagNamePrefix = ""
 if sys.version_info.major == 2:
     BaseStrType_ = basestring
 else:
@@ -201,12 +202,12 @@ except ModulenotfoundExp_ as exp:
                 'str_pretty_print': True,
                 'str_indent_level': 0,
                 'str_namespaceprefix': '',
-                'str_name': None,
+                'str_name': self.__class__.__name__,
                 'str_namespacedefs': '',
             }
             for n in settings:
                 if hasattr(self, n):
-                    setattr(settings[n], self[n])
+                    settings[n] = getattr(self, n)
             if sys.version_info.major == 2:
                 from StringIO import StringIO
             else:
@@ -1018,91 +1019,92 @@ class oneperEnumType01_1(str, Enum):
     TOKEN='token'
 
 
-class oneperType00_1(GeneratedsSuper):
+class oneperType02_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('inner01', 'oneperType01_1', 0, 0, {'name': 'inner01', 'type': 'oneperType01_1'}, None),
-        MemberSpec_('inner02', 'oneperType01_2', 0, 0, {'name': 'inner02', 'type': 'oneperType01_2'}, None),
+        MemberSpec_('clientname', 'xs:string', 0, 0, {'name': 'clientname', 'type': 'xs:string'}, None),
+        MemberSpec_('inner01', 'oneperType02_2', 0, 0, {'name': 'inner01', 'type': 'oneperType02_2'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, inner01=None, inner02=None, gds_collector_=None, **kwargs_):
+    def __init__(self, clientname=None, inner01=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
+        self.clientname = clientname
+        self.clientname_nsprefix_ = None
         self.inner01 = inner01
         self.inner01_nsprefix_ = None
-        self.inner02 = inner02
-        self.inner02_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType00_1)
+                CurrentSubclassModule_, oneperType02_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType00_1.subclass:
-            return oneperType00_1.subclass(*args_, **kwargs_)
+        if oneperType02_1.subclass:
+            return oneperType02_1.subclass(*args_, **kwargs_)
         else:
-            return oneperType00_1(*args_, **kwargs_)
+            return oneperType02_1(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
+    def get_clientname(self):
+        return self.clientname
+    def set_clientname(self, clientname):
+        self.clientname = clientname
     def get_inner01(self):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
-    def get_inner02(self):
-        return self.inner02
-    def set_inner02(self, inner02):
-        self.inner02 = inner02
     def _hasContent(self):
         if (
-            self.inner01 is not None or
-            self.inner02 is not None
+            self.clientname is not None or
+            self.inner01 is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType00_1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType00_1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_1')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType00_1':
+        if self.original_tagname_ is not None and name_ == 'oneperType02_1':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType00_1')
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_1')
         if self._hasContent():
             outfile.write('>%s' % (eol_, ))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType00_1', pretty_print=pretty_print)
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType00_1'):
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_1'):
         pass
-    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType00_1', fromsubclass_=False, pretty_print=True):
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
+        if self.clientname is not None:
+            namespaceprefix_ = self.clientname_nsprefix_ + ':' if (UseCapturedNS_ and self.clientname_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sclientname>%s</%sclientname>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientname), input_name='clientname')), namespaceprefix_ , eol_))
         if self.inner01 is not None:
             namespaceprefix_ = self.inner01_nsprefix_ + ':' if (UseCapturedNS_ and self.inner01_nsprefix_) else ''
             self.inner01.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner01', pretty_print=pretty_print)
-        if self.inner02 is not None:
-            namespaceprefix_ = self.inner02_nsprefix_ + ':' if (UseCapturedNS_ and self.inner02_nsprefix_) else ''
-            self.inner02.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner02', pretty_print=pretty_print)
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1117,21 +1119,120 @@ class oneperType00_1(GeneratedsSuper):
     def _buildAttributes(self, node, attrs, already_processed):
         pass
     def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'inner01':
-            obj_ = oneperType01_1.factory(parent_object_=self)
+        if nodeName_ == 'clientname':
+            value_ = child_.text
+            value_ = self.gds_parse_string(value_, node, 'clientname')
+            value_ = self.gds_validate_string(value_, node, 'clientname')
+            self.clientname = value_
+            self.clientname_nsprefix_ = child_.prefix
+        elif nodeName_ == 'inner01':
+            obj_ = oneperType02_2.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.inner01 = obj_
             obj_.original_tagname_ = 'inner01'
-        elif nodeName_ == 'inner02':
-            obj_ = oneperType01_2.factory(parent_object_=self)
-            obj_.build(child_, gds_collector_=gds_collector_)
-            self.inner02 = obj_
-            obj_.original_tagname_ = 'inner02'
-# end class oneperType00_1
+# end class oneperType02_1
+
+
+class oneperType02_2(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = [
+        MemberSpec_('clientdescription', 'xs:string', 0, 0, {'name': 'clientdescription', 'type': 'xs:string'}, None),
+    ]
+    subclass = None
+    superclass = None
+    def __init__(self, clientdescription=None, gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.gds_elementtree_node_ = None
+        self.original_tagname_ = None
+        self.parent_object_ = kwargs_.get('parent_object_')
+        self.ns_prefix_ = None
+        self.clientdescription = clientdescription
+        self.clientdescription_nsprefix_ = None
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, oneperType02_2)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if oneperType02_2.subclass:
+            return oneperType02_2.subclass(*args_, **kwargs_)
+        else:
+            return oneperType02_2(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_ns_prefix_(self):
+        return self.ns_prefix_
+    def set_ns_prefix_(self, ns_prefix):
+        self.ns_prefix_ = ns_prefix
+    def get_clientdescription(self):
+        return self.clientdescription
+    def set_clientdescription(self, clientdescription):
+        self.clientdescription = clientdescription
+    def _hasContent(self):
+        if (
+            self.clientdescription is not None
+        ):
+            return True
+        else:
+            return False
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_2')
+        if imported_ns_def_ is not None:
+            namespacedef_ = imported_ns_def_
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.original_tagname_ is not None and name_ == 'oneperType02_2':
+            name_ = self.original_tagname_
+        if UseCapturedNS_ and self.ns_prefix_:
+            namespaceprefix_ = self.ns_prefix_ + ':'
+        showIndent(outfile, level, pretty_print)
+        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
+        already_processed = set()
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_2')
+        if self._hasContent():
+            outfile.write('>%s' % (eol_, ))
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_2', pretty_print=pretty_print)
+            showIndent(outfile, level, pretty_print)
+            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
+        else:
+            outfile.write('/>%s' % (eol_, ))
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_2'):
+        pass
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', fromsubclass_=False, pretty_print=True):
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.clientdescription is not None:
+            namespaceprefix_ = self.clientdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.clientdescription_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sclientdescription>%s</%sclientdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientdescription), input_name='clientdescription')), namespaceprefix_ , eol_))
+    def build(self, node, gds_collector_=None):
+        self.gds_collector_ = gds_collector_
+        if SaveElementTreeNode:
+            self.gds_elementtree_node_ = node
+        already_processed = set()
+        self.ns_prefix_ = node.prefix
+        self._buildAttributes(node, node.attrib, already_processed)
+        for child in node:
+            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
+            self._buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
+        return self
+    def _buildAttributes(self, node, attrs, already_processed):
+        pass
+    def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+        if nodeName_ == 'clientdescription':
+            value_ = child_.text
+            value_ = self.gds_parse_string(value_, node, 'clientdescription')
+            value_ = self.gds_validate_string(value_, node, 'clientdescription')
+            self.clientdescription = value_
+            self.clientdescription_nsprefix_ = child_.prefix
+# end class oneperType02_2
 
 
 GDSClassesMapping = {
-    'root00': oneperType00_1,
+    'root02': oneperType02_1,
 }
 
 
@@ -1147,9 +1248,10 @@ def usage():
 
 def get_root_tag(node):
     tag = Tag_pattern_.match(node.tag).groups()[-1]
-    rootClass = GDSClassesMapping.get(tag)
+    prefix_tag = TagNamePrefix + tag
+    rootClass = GDSClassesMapping.get(prefix_tag)
     if rootClass is None:
-        rootClass = globals().get(tag)
+        rootClass = globals().get(prefix_tag)
     return tag, rootClass
 
 
@@ -1178,8 +1280,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType00_1'
-        rootClass = oneperType00_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1210,8 +1312,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType00_1'
-        rootClass = oneperType00_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if mapping is None:
@@ -1256,8 +1358,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType00_1'
-        rootClass = oneperType00_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1284,8 +1386,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType00_1'
-        rootClass = oneperType00_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1293,8 +1395,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
         doc = None
         rootNode = None
 ##     if not silence:
-##         sys.stdout.write('#from oneperType00_1One import *\n\n')
-##         sys.stdout.write('import oneperType00_1One as model_\n\n')
+##         sys.stdout.write('#from oneperType02_1One import *\n\n')
+##         sys.stdout.write('import oneperType02_1One as model_\n\n')
 ##         sys.stdout.write('rootObj = model_.rootClass(\n')
 ##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
@@ -1324,11 +1426,8 @@ RenameMappings_ = {
 
 }
 __all__ = [
-    "oneperType00_1",
     "oneperType01_1",
     "oneperType01_2",
     "oneperType02_1",
-    "oneperType02_2",
-    "oneperType03_1",
-    "oneperType03_2"
+    "oneperType02_2"
 ]
