@@ -44,6 +44,7 @@ from lxml import etree as etree_
 
 Validate_simpletypes_ = True
 SaveElementTreeNode = True
+TagNamePrefix = ""
 if sys.version_info.major == 2:
     BaseStrType_ = basestring
 else:
@@ -203,12 +204,12 @@ class GeneratedsSuper(object):
             'str_pretty_print': True,
             'str_indent_level': 0,
             'str_namespaceprefix': '',
-            'str_name': None,
+            'str_name': self.__class__.__name__,
             'str_namespacedefs': '',
         }
         for n in settings:
             if hasattr(self, n):
-                setattr(settings[n], self[n])
+                settings[n] = getattr(self, n)
         if sys.version_info.major == 2:
             from StringIO import StringIO
         else:
@@ -1112,9 +1113,10 @@ def usage():
 
 def get_root_tag(node):
     tag = Tag_pattern_.match(node.tag).groups()[-1]
-    rootClass = GDSClassesMapping.get(tag)
+    prefix_tag = TagNamePrefix + tag
+    rootClass = GDSClassesMapping.get(prefix_tag)
     if rootClass is None:
-        rootClass = globals().get(tag)
+        rootClass = globals().get(prefix_tag)
     return tag, rootClass
 
 
