@@ -1269,6 +1269,24 @@ class GenTest(unittest.TestCase):
         self.remove('{}2_sup.py'.format(t_))
         self.remove('{}2_sub.py'.format(t_))
 
+    def test_049_episodic_compilation(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--silence --member-specs dict -f '
+            '--one-file-per-xsd '
+            '--use-source-file-as-module-name '
+            '--namespace-to-import-path-configuration-file '
+            'tests/episodic.json '
+            '--output-directory tests '
+            'tests/%s.xsd'
+        )
+        t_ = 'episodic_second'
+        cmd = cmdTempl % (t_, )
+        self.executeClean(cmd)
+        self.compareFiles('{}.py'.format(t_), '{}2.py'.format(t_))
+        # cleanup generated files
+        self.remove('{}.py'.format(t_))
+
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
         right = os.path.join(TEST_DIR, right)
